@@ -831,7 +831,7 @@ class Builder(Update):
                 else:
                     yield f'{pkg.category}/{pkg.pkg}'
 
-                path_to_repo = pathJoin(builder_path, pkg.repository)
+                path_to_repo = pathJoin(builder_path, pkg.repository[1])
                 path_to_file = pathJoin(path_to_repo, meta_suffix_path, pkg[0], pkg[1])
                 if not path.exists(path_to_file):
                     continue
