@@ -2055,10 +2055,16 @@ class VariableClUpdateIgnoreLevel(Variable):
     type = "bool"
     value = "on"
 
+
 class VariableClCheckUpdateLevel(Variable):
     """
     Проверять уровень обновления 
     при соединении с binhost
     """
     type = "bool"
-    value = "off"
\ No newline at end of file
+    value = "off"
+
+
+class VariableClBuilderPkgCachePath(Variable):
+    type = "string"
+    value = "/var/calculate/remote/"
